section — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- admin »

# section

class `camelot.admin.section.` `Section`(verbose_name, application_admin, icon=None, items=[])

  A Section as displayed in the left pane of the application. Each Section contains a list of SectionItems the user can click on. Sections should be used in the definition of the Application admin:

class `camelot.admin.section.` `SectionItem`(action, application_admin, verbose_name=None)

  An item inside a section, the user can click on and trigger an action.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- admin »

Comments
blog comments powered by Disqus